import type { AxiosInstance } from 'axios';
import request from '/@/utils/request';
export type RunAnalyConfigureGetAllResItem = {
	ID: string;
	ObjectType: string;
	ObjectID: string;
	Frequency: number;
	ChangeTimes: number;
	Description: string;
};

export type RunAnalyConfigurePostParams = {
	ObjectType: string;
	ObjectID: string;
	Frequency: number;
	ChangeTimes: number;
	Description?: string;
};

export type RunAnalyConfigurePutParams = {
	ID: string;
	Frequency: number;
	ChangeTimes: number;
	Description?: string;
};

/**
 * @summary 获取所有运行分析配置
 */
export const GetAllRunAnalyConfigure = async (req: AxiosInstance = request) => {
	return req<RunAnalyConfigureGetAllResItem[]>({
		url: '/Run/Analy/Configure/GetAll@V1.0',
		method: 'get',
	});
};

/**
 * @summary GetRunAnalyConfigureByObjectTypeAndObjectID
 */
export const GetRunAnalyConfigureByObjectTypeAndObjectID = async (params, req: AxiosInstance = request) => {
	return req<RunAnalyConfigureGetAllResItem[]>({
		url: '/Run/Analy/Configure/GetByObjectTypeAndObjectID@V1.0',
		method: 'get',
		params,
	});
};

/**
 * @summary 添加一个运行分析配置
 */
export const InsertARunAnalyConfigure = async (data: RunAnalyConfigurePostParams, req: any = request) => {
	return req({
		url: '/Run/Analy/Configure/Insert@V1.0',
		method: 'post',
		data,
	});
};

/**
 * @summary 修改一个运行分析配置
 */
export const UpdateARunAnalyConfigure = async (data: RunAnalyConfigurePutParams, req: any = request) => {
	return req({
		url: '/Run/Analy/Configure/Update@V1.0',
		method: 'put',
		data,
	});
};

/**
 * @summary SetRunAnalyConfigure
 */
export const SetRunAnalyConfigure = async (data, req: AxiosInstance = request) => {
	return req({
		url: '/Run/Analy/Configure/Set@V1.0',
		method: 'post',
		data,
	});
};

/**
 * @summary 删除一个运行分析配置
 */
export const DeleteARunAnalyConfigure = async (params, req: any = request) => {
	return req({
		url: '/Run/Analy/Configure/DeleteByID@V1.0',
		method: 'delete',
		params,
	});
};
